pub struct D1DatabaseSession(/* private fields */);Expand description
A D1 session that provides sequential consistency between queries.
Implementations
Sourceimpl D1DatabaseSession
impl D1DatabaseSession
Sourcepub fn prepare<T: Into<String>>(&self, query: T) -> D1PreparedStatement
pub fn prepare<T: Into<String>>(&self, query: T) -> D1PreparedStatement
Prepare a query statement from a query string.
Sourcepub async fn batch(
&self,
statements: Vec<D1PreparedStatement>,
) -> Result<Vec<D1Result>>
pub async fn batch( &self, statements: Vec<D1PreparedStatement>, ) -> Result<Vec<D1Result>>
Batch execute one or more statements against the database using this session.
Returns the results in the same order as the provided statements.
Sourcepub fn get_bookmark(&self) -> Result<Option<D1SessionBookmark>>
pub fn get_bookmark(&self) -> Result<Option<D1SessionBookmark>>
Returns the latest bookmark seen by this session.
If no query has been executed in this session yet, returns None.