pub struct ForwardableEmailMessage { /* private fields */ }Implementations
Sourceimpl ForwardableEmailMessage
impl ForwardableEmailMessage
Sourcepub fn raw(&self) -> ReadableStream
pub fn raw(&self) -> ReadableStream
Stream of the email message content.
Sourceimpl ForwardableEmailMessage
impl ForwardableEmailMessage
Sourcepub fn headers(&self) -> Headers
pub fn headers(&self) -> Headers
An Headers object.
Sourceimpl ForwardableEmailMessage
impl ForwardableEmailMessage
Sourcepub fn set_reject(&self, reason: &str)
pub fn set_reject(&self, reason: &str)
Reject this email message by returning a permanent SMTP error back to the connecting client including the given reason.
reason- The reject reason.
Returns: void
Sourceimpl ForwardableEmailMessage
impl ForwardableEmailMessage
Sourcepub async fn forward(&self, rcpt_to: &str) -> Result<EmailSendResult, Error>
pub async fn forward(&self, rcpt_to: &str) -> Result<EmailSendResult, Error>
Forward this email message to a verified destination address of the account.
rcptTo- Verified destination address.headers- A Headers object.
Returns: A promise that resolves when the email message is forwarded.
Sourceimpl ForwardableEmailMessage
impl ForwardableEmailMessage
Sourcepub async fn forward_with_headers(
&self,
rcpt_to: &str,
headers: &Headers,
) -> Result<EmailSendResult, Error>
pub async fn forward_with_headers( &self, rcpt_to: &str, headers: &Headers, ) -> Result<EmailSendResult, Error>
Forward this email message to a verified destination address of the account.
rcptTo- Verified destination address.headers- A Headers object.
Returns: A promise that resolves when the email message is forwarded.
Sourceimpl ForwardableEmailMessage
impl ForwardableEmailMessage
Sourcepub async fn reply(
&self,
message: &EmailMessage,
) -> Result<EmailSendResult, Error>
pub async fn reply( &self, message: &EmailMessage, ) -> Result<EmailSendResult, Error>
Reply to the sender of this email message with a new EmailMessage object.
message- The reply message.
Returns: A promise that resolves when the email message is replied.
Sourceimpl ForwardableEmailMessage
impl ForwardableEmailMessage
Sourcepub fn raw_byte_stream(&self) -> ByteStream
pub fn raw_byte_stream(&self) -> ByteStream
Stream of the raw email content.
Methods from Deref<Target = EmailMessage>
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
👎Deprecated: Use Object::hasOwn instead.
pub fn has_own_property(&self, property: &JsValue) -> bool
Use Object::hasOwn instead.
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Sourcepub fn to_js_string(&self) -> JsString
pub fn to_js_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn as_f64(&self) -> Option<f64>
pub fn as_f64(&self) -> Option<f64>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Sourcepub fn as_string(&self) -> Option<String>
pub fn as_string(&self) -> Option<String>
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Tests whether this JS value is undefined
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Tests whether this JS value is null or undefined
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Tests whether the type of this JS value is function.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Applies the binary in JS operator on the two JsValues.
Sourcepub fn loose_eq(&self, other: &JsValue) -> bool
pub fn loose_eq(&self, other: &JsValue) -> bool
Compare two JsValues for equality, using the == operator in JS.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Applies the binary >>> JS operator on the two JsValues.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Sourcepub fn pow(&self, rhs: &JsValue) -> JsValue
pub fn pow(&self, rhs: &JsValue) -> JsValue
Applies the binary ** JS operator on the two JsValues.
Sourcepub fn lt(&self, other: &JsValue) -> bool
pub fn lt(&self, other: &JsValue) -> bool
Applies the binary < JS operator on the two JsValues.
Sourcepub fn le(&self, other: &JsValue) -> bool
pub fn le(&self, other: &JsValue) -> bool
Applies the binary <= JS operator on the two JsValues.
Sourcepub fn ge(&self, other: &JsValue) -> bool
pub fn ge(&self, other: &JsValue) -> bool
Applies the binary >= JS operator on the two JsValues.
Sourcepub fn gt(&self, other: &JsValue) -> bool
pub fn gt(&self, other: &JsValue) -> bool
Applies the binary > JS operator on the two JsValues.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Applies the unary + JS operator on a JsValue. Can throw.